TRANSLATION = {
    "récupérer": "get",
    "gousse": "pod",
    "gousses": "pods",
    "modifier": "edit",
    "créer": "create",
    "espace-de-nom": "namespace",
    "espaces-de-nom": "namespaces"
}
